document.addEventListener('DOMContentLoaded', function() {
    // 获取DOM元素（带安全检查）
    const elements = {
        refreshBtn: document.getElementById('refresh-btn'),
        themeToggle: document.getElementById('theme-toggle'),
        statsTable: document.getElementById('stats-table')?.getElementsByTagName('tbody')[0],
        whitelistPlayers: document.getElementById('whitelist-players'),
        nonWhitelistPlayers: document.getElementById('non-whitelist-players'),
        totalCount: document.getElementById('total-count'),
        whitelistCount: document.getElementById('whitelist-count'),
        nonWhitelistCount: document.getElementById('non-whitelist-count'),
        memoryUsed: document.getElementById('memory-used'),
        memoryFree: document.getElementById('memory-free'),
        memoryPercent: document.getElementById('memory-percent'),
        avgTick: document.getElementById('avg-tick'),
        uptime: document.getElementById('uptime')
    };

    // 初始化主题
    const savedTheme = localStorage.getItem('theme') || 'light';
    document.documentElement.setAttribute('data-theme', savedTheme);

    // 主题切换
    if (elements.themeToggle) {
        elements.themeToggle.addEventListener('click', toggleTheme);
    }

    // 刷新按钮
    if (elements.refreshBtn) {
        elements.refreshBtn.addEventListener('click', handleRefresh);
    }

    // 初始化图表
    const memoryChart = initMemoryChart();
    const performanceChart = initPerformanceChart();

    // 初始加载数据
    loadAllData();

    // 设置定时刷新（10秒）
    setInterval(loadAllData, 10000);

    /*** 功能函数 ***/
    function toggleTheme() {
        const currentTheme = document.documentElement.getAttribute('data-theme');
        const newTheme = currentTheme === 'light' ? 'dark' : 'light';
        document.documentElement.setAttribute('data-theme', newTheme);
        localStorage.setItem('theme', newTheme);
    }

    function handleRefresh() {
        this.classList.add('loading');
        loadAllData();
        setTimeout(() => {
            this.classList.remove('loading');
        }, 1000);
    }

    function initMemoryChart() {
        const ctx = document.getElementById('memory-chart')?.getContext('2d');
        if (!ctx) return null;

        return new Chart(ctx, {
            type: 'doughnut',
            data: {
                labels: ['已使用', '未使用'],
                datasets: [{
                    data: [0, 100],
                    backgroundColor: ['#4361ee', '#e9ecef']
                }]
            },
            options: {
                responsive: true,
                maintainAspectRatio: false
            }
        });
    }

    function initPerformanceChart() {
        const ctx = document.getElementById('performance-chart')?.getContext('2d');
        if (!ctx) return null;

        return new Chart(ctx, {
            type: 'line',
            data: {
                labels: Array(10).fill('').map((_, i) => i + 1),
                datasets: [{
                    label: 'Tick时间 (ms)',
                    data: Array(10).fill(0),
                    borderColor: '#4361ee',
                    tension: 0.1,
                    fill: false
                }]
            },
            options: {
                responsive: true,
                maintainAspectRatio: false,
                scales: {
                    y: {
                        beginAtZero: true,
                        title: {
                            display: true,
                            text: '毫秒'
                        }
                    }
                }
            }
        });
    }

    async function loadAllData() {
        try {
            await Promise.all([
                fetchData('/api/stats', updateTable),
                fetchData('/api/online-players', updateOnlinePlayers),
                fetchData('/api/player-count', updatePlayerCounts),
                fetchData('/api/server-status', (data) => updateServerStatus(data, memoryChart, performanceChart))
            ]);
        } catch (error) {
            console.error('加载数据出错:', error);
            showError('加载数据失败，请检查控制台');
        }
    }

    async function fetchData(url, callback) {
        try {
            const response = await fetch(url);
            if (!response.ok) throw new Error(`HTTP error! status: ${response.status}`);
            const data = await response.json();
            callback(data);
        } catch (error) {
            console.error(`获取 ${url} 数据失败:`, error);
            throw error;
        }
    }

    function updateTable(data) {
        if (!elements.statsTable) return;

        elements.statsTable.innerHTML = '';
        const sortedPlayers = Object.entries(data)
            .map(([name, statString]) => {
                const stats = {};
                statString.split(" | ").forEach(part => {
                    const [label, value] = part.split(": ");
                    stats[label.trim()] = value;
                });
                return { name, stats };
            })
            .sort((a, b) => parseTimeToSeconds(b.stats["总时长"]) - parseTimeToSeconds(a.stats["总时长"]));

        sortedPlayers.forEach(player => {
            const row = elements.statsTable.insertRow();
            row.insertCell(0).textContent = player.name;
            row.insertCell(1).textContent = player.stats["总时长"];
            row.insertCell(2).textContent = player.stats["30天"];
            row.insertCell(3).textContent = player.stats["7天"];
        });
    }

    function updateOnlinePlayers(data) {
        if (!elements.whitelistPlayers || !elements.nonWhitelistPlayers) return;

        const updateList = (element, players, emptyMessage) => {
            element.innerHTML = '';
            if (players?.length > 0) {
                players.forEach(player => {
                    const li = document.createElement('li');
                    li.innerHTML = `<span class="player-name">${player.name}</span>`;
                    element.appendChild(li);
                });
            } else {
                element.innerHTML = `<li>${emptyMessage}</li>`;
            }
        };

        updateList(elements.whitelistPlayers, data.whitelisted, '暂无玩家在线');
        updateList(elements.nonWhitelistPlayers, data.non_whitelisted, '暂无假人在线');
    }

    function updatePlayerCounts(data) {
        if (elements.totalCount) elements.totalCount.textContent = data.total || 0;
        if (elements.whitelistCount) elements.whitelistCount.textContent = data.whitelisted || 0;
        if (elements.nonWhitelistCount) elements.nonWhitelistCount.textContent = data.non_whitelisted || 0;
    }

    function updateServerStatus(data, memoryChart, performanceChart) {
        // 更新内存信息
        if (data.memory) {
            const usedMB = Math.round(data.memory.used / (1024 * 1024));
            const freeMB = Math.round((data.memory.max - data.memory.used) / (1024 * 1024));
            const percent = Math.round(data.memory.usage_percentage);

            if (memoryChart) {
                memoryChart.data.datasets[0].data = [usedMB, freeMB];
                memoryChart.update();
            }

            if (elements.memoryUsed) elements.memoryUsed.textContent = usedMB;
            if (elements.memoryFree) elements.memoryFree.textContent = freeMB;
            if (elements.memoryPercent) elements.memoryPercent.textContent = percent;
        }

        // 更新性能信息
        if (data.server) {
            if (performanceChart && data.server.recent_tick_samples_ms) {
                performanceChart.data.datasets[0].data = data.server.recent_tick_samples_ms;
                performanceChart.update();
            }

            if (elements.avgTick) elements.avgTick.textContent = data.server.average_tick_time_ms?.toFixed(2) || '0';
        }

        if (elements.uptime) elements.uptime.textContent = data.uptime_formatted || '0';
    }

    function parseTimeToSeconds(timeStr) {
        if (!timeStr) return 0;
        return timeStr.split(' ').reduce((total, part) => {
            if (part.includes('h')) return total + parseInt(part.replace('h', '')) * 3600;
            if (part.includes('m')) return total + parseInt(part.replace('m', '')) * 60;
            return total;
        }, 0);
    }

    function showError(message) {
        const errorEl = document.createElement('div');
        errorEl.className = 'error-message';
        errorEl.textContent = message;
        document.body.appendChild(errorEl);

        setTimeout(() => {
            errorEl.classList.add('show');
            setTimeout(() => {
                errorEl.classList.remove('show');
                setTimeout(() => document.body.removeChild(errorEl), 300);
            }, 5000);
        }, 10);
    }
});
